#####################################################################
##  rpud : An R packge for GPU computing
##  Copyright (C) 2010-2018 Chi Yau
##

test.path <- file.path(path.package(package="rpud"), "runit/data/rpudl")


#####################################################################


test.rpudl.mnist <- function(x) {

    ds <- rpudlCreateDataSource(
            data.format="lmdb",
            data.dir=file.path(test.path, "mnist"),
            train.data="mnist-40-12-data_train_lmdb",
            test.data="mnist-40-12-data_test_lmdb",
            data.shape=c(28, 28)
    )
    
    model <- rpudl(
            file.path(test.path, "mnist/caffe_mnist_small_train.prototxt"),
            data.source=ds
    )
    model <- rpudlTrain(model, batch=2, iter=60)
    
    obj <- rpudlGetTestingDataSamples(ds, c(1, 2))
    res <- predict(model, obj$x)
    print(attr(res, "decision.values"))
    
    A <- t(matrix(c(
             0.1018379, 0.1018380,
             0.1274917, 0.1274917,
             0.0982756, 0.0982756,
             0.1149030, 0.1149029,
             0.0956398, 0.0956398,
             0.0809795, 0.0809795,
             0.1270290, 0.1270290,
             0.0858817, 0.0858817,
             0.0689210, 0.0689210,
             0.0990409, 0.0990409
            ), nrow=2))
    checkEqualsNumeric(
            attr(res, "decision.values"),
            A, tolerance=1.e-05
    )
}


test.rpudl.cifar10 <- function(x) {
    
    ds <- rpudlCreateDataSource(
            data.format="lmdb",
            data.dir=file.path(test.path, "cifar10"),
            train.data="samples_train_lmdb",
            test.data="samples_test_lmdb",
            data.shape=c(32, 32),
            data.channels=3
    )
    #rpudl.data.mean(ds, filename="samples.mean")
    
    model <- rpudl(
            file.path(test.path, "cifar10/cifar10_small_train.prototxt"),
            data.source=ds
    )
    model <- rpudlTrain(model, batch=2, iter=4)
    
    obj <- rpudlGetTestingDataSamples(ds, c(1, 2))
    res <- predict(model, obj$x)
    print(attr(res, "decision.values"))
    
    A <- t(matrix(c(
            0.0998189, 0.0998189,
            0.1001989, 0.1001989,
            0.0998189, 0.0998189,
            0.0998189, 0.0998189,
            0.1000897, 0.1000897,
            0.0998189, 0.0998189,
            0.1002628, 0.1002628,
            0.0998189, 0.0998189,
            0.0998189, 0.0998189,
            0.1005348, 0.1005348
            ), nrow=2))
    checkEqualsNumeric(
            attr(res, "decision.values"),
            A, tolerance=1.5e-05
    )
}


